@@ -1,7 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * libloqui -- Chat/IM client library for GLib <http://loqui.good-day.net/>
- * Copyright (C) 2002-2004 Yoichi Imai <yoichi@silver-forest.com>
+ * libloqui -- Chat/IM client library for GLib <http://launchpad.net/loqui/>
+ * Copyright (C) 2002-2004 Yoichi Imai <sunnyone41@gmail.com>
  *
  * This Library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public License as
@@ -418,7 +418,13 @@ loqui_channel_entry_add_real(LoquiChannelEntry *chent, LoquiMember *member)
         priv = chent->priv;
 
 	if (g_hash_table_lookup(chent->user_hash, member->user) != 0) {
-		g_warning("The user is already registered.");
+                gchar *identifier = loqui_user_get_identifier(member->user);
+
+		g_warning("The user (%s) is already registered to '%s'.",
+                          identifier,
+                          loqui_channel_entry_get_name(chent));
+
+                g_free(identifier);
 		return;
 	}
 
